==> vala-0.1.2.tar.bz2: vala-0.1.2/vala/valastatement.c <==
/* valastatement.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valastatement.h"



static void vala_statement_base_init (ValaStatementIface * iface)
{
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType vala_statement_get_type (void)
{
	static GType vala_statement_type_id = 0;
	if (G_UNLIKELY (vala_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaStatementIface), (GBaseInitFunc) vala_statement_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
		vala_statement_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaStatement", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (vala_statement_type_id, VALA_TYPE_CODE_NODE);
	}
	return vala_statement_type_id;
}

==> vala-0.5.1.tar.bz2: vala-0.5.1/vala/valastatement.c <==
/* valastatement.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valastatement.h>







static void vala_statement_base_init (ValaStatementIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType vala_statement_get_type (void) {
	static GType vala_statement_type_id = 0;
	if (vala_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaStatementIface), (GBaseInitFunc) vala_statement_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		vala_statement_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaStatement", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (vala_statement_type_id, VALA_TYPE_CODE_NODE);
	}
	return vala_statement_type_id;
}
